/*!
* \file gamePackage.c
* \brief Fichier contenant le code des fonctions liees aux gamePackage.
*/

#include "structures.h"
#include "roxml.h"
#include "Interface.h"
#include "gamePackage.h"
#include "classe.h"
#include "terrain.h"
#include "carte.h"

/*!
 * \fn Game_Package Construire_Package()
 * \brief Fonction de construction d'un package contenant l'univers du jeu
 *
 * \return un Game_Package
 */
Game_Package Construire_Package()
{
    Game_Package Pack;

    Classe* Classes_Pack = Librairie_Classes("../resources/Classes.xml");
    Pack.nbClasses = getNbElements("../resources/Classes.xml");

    Terrain* Terrains_Pack = Librairie_Terrains("../resources/Terrains.xml");
    Pack.nbTerrains=getNbElements("../resources/Terrains.xml");

    Skins_GUI* GUI_Pack = Get_Skins_GUI("../resources/GUI.xml");

    Carte_A* Map_Pack = ExtraireCartesXML("../resources/Maps.xml");
    Pack.nbCartes = getNbElements("../resources/Maps.xml");

    Pack.Classes_Package = Classes_Pack;
    Pack.Terrains_Package = Terrains_Pack;
    Pack.GUI_Package = GUI_Pack;
    Pack.Cartes_Package = Map_Pack;

    return Pack;
}

/*!
 * \fn int getNbElements(char * file)
 * \brief Fonction determinant le nombre de d'lments dans un fichier XML
 *
 * \param le fichier  tester.
 * \return le nombre d'lements dans le fichier.
 */
int getNbElements(char * file){

    node_t *rootXML, *Element;

    rootXML = roxml_load_doc(file);            /* Ouvre le doc XML et cr le noeud de base */
    Element = roxml_get_chld(rootXML, NULL, 0);    /* Descend d'un niveau dans l'arborescence */

    return roxml_get_chld_nb(Element);    /* Rcupre le nombre de classes entres dans le fichier XML */
}

/*!
 * \fn int getNbClasses(Game_Package pack)
 * \brief Fonction retournant le nombre de classes d'un Game_Package
 *
 * \param le Game_Package  tester.
 * \return le nombre de classes du Game_Package.
 */
int getNbClasses(Game_Package pack){
    return pack.nbClasses;
}

/*!
 * \fn int getNbClasses(Game_Package pack)
 * \brief Fonction retournant le nombre de classes d'un Game_Package
 *
 * \param le Game_Package  tester.
 * \return le nombre de classes du Game_Package.
 */
int getNbCartes(Game_Package pack){
    return pack.nbCartes;
}

int getNbTerrains(Game_Package pack){
    return pack.nbTerrains;
}
